@@ -29,9 +29,7 @@ pub const BCM_CHANGE_BRIGHTNESS_PRODUCER_CODE: u16 = 0x0003;
 pub const BCM_CHANGE_BRIGHTNESS_STATE_PRODUCER_CODE: u16 = 0x0004;
 pub const BCM_ANIMATE_BRIGHTNESS_PRODUCER_CODE: u16 = 0x0005;
 pub const BCM_ANIMATE_BRIGHTNESS_STATE_PRODUCER_CODE: u16 = 0x0006;
-pub const RELAY_SET_STATE_PRODUCER_CODE: u16 = 0x0007;
-pub const RELAY_SET_STATE_STATE_PRODUCER_CODE: u16 = 0x0008;
-pub const RELAY_FLIP_STATE_PRODUCER_CODE: u16 = 0x0009;
+pub const RELAY_SET_VALUE_PRODUCER_CODE: u16 = 0x0007;
 
 #[derive(Debug, PartialEq)]
 pub enum ProducerError {
